@@ -41,7 +41,7 @@ NAME_MAP = {
     'nc_feed_history': '喂养史',
     'nc_growth_history': '发育史',
     "nc_physical_exam": '专科体格检查',
-    'nc_fist_disease_course': '首次病程',
+    'nc_fist_disease_course': '首次病程记录',
     'nc_case_characteristics': '病例特点',
     'nc_primary_diagnosis': '初步诊断',
     'nc_primary_diagnosis_basis': '初步诊断依据',
